library("lsmeans")
library(lme4)

#####SETTING UP THE DATA#####
#'load already set up diploid data file
nys.dips <- read.csv("GrowthRateAssays/data_output/lgrNys2Dips.csv", sep=",", as.is=TRUE)

#'make log(OD) column
nys.dips$logK24.nys <- log(nys.dips$K24.nys)

#'make day, plate, genotype into factors
nys.dips$nbm8 <- factor(nys.dips$nbm8, levels=c("w","t","m"))
nys.dips$nbm12 <- factor(nys.dips$nbm12, levels=c("w","t","m"))
nys.dips$nbm45 <- factor(nys.dips$nbm45, levels=c("w","t","m"))
nys.dips$nbm58 <- factor(nys.dips$nbm58, levels=c("w","t","m"))
nys.dips$Day <- factor(nys.dips$Day)
nys.dips$Plate <- factor(nys.dips$Plate)

#####MODEL - NYSTATIN2 DIPLOIDS, NO HETEROZYGOTES#####
#'write full model
#'plate within day as random effect
dat <- nys.dips[is.na(nys.dips$omit)&is.na(nys.dips$out)&nys.dips$type=="m",]
nys.dips.m.model <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.dips.m.model),residuals(nys.dips.m.model))
abline(h=0)
hist(residuals(nys.dips.m.model))
qqnorm(residuals(nys.dips.m.model))
qqline(residuals(nys.dips.m.model))
#'plot
boxplot(logK24.nys ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(nys.dips.m.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'find the least-squares means (and confidence intervals) for each line
nys.dips.m.lsmeans <- summary(lsmeans(nys.dips.m.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(nys.dips.m.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,m,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,m,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
nys.dips.m.contrasts <- summary(contrast(lsmeans(nys.dips.m.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(nys.dips.m.lsmeans, digits=5), "GR.OpticalDensity/data_output/Nys2DipsMMeans.OD.csv", row.names=FALSE)
write.csv(format(nys.dips.m.contrasts, digits=5), "GR.OpticalDensity/data_output/Nys2DipsMContrasts.OD.csv", row.names=FALSE)

#####MODEL - NYSTATIN2 DIPLOIDS, INCLUDING HETEROZYGOTES#####
#'write full model
#'plate within day as random effect
dat <- nys.dips[is.na(nys.dips$omit)&is.na(nys.dips$out),]
nys.dips.t.model <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.dips.t.model),residuals(nys.dips.t.model))
abline(h=0)
hist(residuals(nys.dips.t.model))
qqnorm(residuals(nys.dips.t.model))
qqline(residuals(nys.dips.t.model))
#'plot
boxplot(logK24.nys ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(nys.dips.t.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(logK24.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'find the least-squares means (and confidence intervals) for each line
nys.dips.t.lsmeans <- summary(lsmeans(nys.dips.t.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do
con <- summary(contrast(lsmeans(nys.dips.t.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - t,w,w,w","w,w,w,w - w,t,w,w","w,w,w,w - w,w,t,w","w,w,w,w - w,w,w,t","w,w,w,w - t,t,w,w","w,w,w,w - t,w,t,w","w,w,w,w - t,w,w,t","w,w,w,w - w,t,t,w","w,w,w,w - w,t,w,t","w,w,w,w - w,w,t,t","t,w,w,w - t,t,w,w","t,w,w,w - t,w,t,w","t,w,w,w - t,w,w,t","w,t,w,w - t,t,w,w","w,t,w,w - w,t,t,w",  "w,t,w,w - w,t,w,t","w,w,t,w - t,w,t,w",  "w,w,t,w - w,t,t,w","w,w,t,w - w,w,t,t","w,w,w,t - t,w,w,t","w,w,w,t - w,t,w,t","w,w,w,t - w,w,t,t","t,w,w,w - m,w,w,w","w,t,w,w - w,m,w,w",  "w,w,t,w - w,w,m,w",  "w,w,w,t - w,w,w,m","m,w,w,w - t,t,w,w","m,w,w,w - t,w,t,w","m,w,w,w - t,w,w,t","t,t,w,w - w,m,w,w","w,m,w,w - w,t,t,w",  "w,m,w,w - w,t,w,t","t,w,t,w - w,w,m,w","w,t,t,w - w,w,m,w","w,w,m,w - w,w,t,t","t,w,w,t - w,w,w,m","w,t,w,t - w,w,w,m","w,w,t,t - w,w,w,m","m,w,w,w - m,t,w,w","m,w,w,w - m,w,t,w",  "m,w,w,w - m,w,w,t","w,m,w,w - t,m,w,w",  "w,m,w,w - w,m,t,w","w,m,w,w - w,m,w,t", "w,w,m,w - t,w,m,w",  "w,w,m,w - w,t,m,w","w,w,m,w - w,w,m,t","w,w,w,m - t,w,w,m","w,w,w,m - w,t,w,m","w,w,w,m - w,w,t,m","t,t,w,w - m,t,w,w","t,t,w,w - t,m,w,w","t,w,t,w - m,w,t,w","t,w,t,w - t,w,m,w","t,w,w,t - m,w,w,t","t,w,w,t - t,w,w,m","w,t,t,w - w,m,t,w","w,t,t,w - w,t,m,w","w,t,w,t - w,m,w,t","w,t,w,t - w,t,w,m","w,w,t,t - w,w,m,t","w,w,t,t - w,w,t,m","m,t,w,w - m,m,w,w","t,m,w,w - m,m,w,w","m,w,t,w - m,w,m,w","t,w,m,w - m,w,m,w","m,w,w,t - m,w,w,m","t,w,w,m - m,w,w,m","w,m,t,w - w,m,m,w","w,t,m,w - w,m,m,w","w,m,w,t - w,m,w,m","w,t,w,m - w,m,w,m","w,w,m,t - w,w,m,m","w,w,t,m - w,w,m,m","t,t,w,w - m,m,w,w","t,w,t,w - m,w,m,w","t,w,w,t - m,w,w,m","w,t,t,w - w,m,m,w","w,t,w,t - w,m,w,m","w,w,t,t - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
nys.dips.t.contrasts <- summary(contrast(lsmeans(nys.dips.t.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(nys.dips.t.lsmeans, digits=5), "GR.OpticalDensity/data_output/Nys2DipsTMeans.OD.csv", row.names=FALSE)
write.csv(format(nys.dips.t.contrasts, digits=5), "GR.OpticalDensity/data_output/Nys2DipsTContrasts.OD.csv", row.names=FALSE)
