library("lsmeans")
library(lme4)

#####SETTING UP THE DATA#####
#'load already set up diploid data file
ypd.dips <- read.csv("GrowthRateAssays/data_output/lgrYPDDips.csv", sep=",", as.is=TRUE)

#'make day, plate, genotype into factors
ypd.dips$nbm8 <- factor(ypd.dips$nbm8, levels=c("w","t","m"))
ypd.dips$nbm12 <- factor(ypd.dips$nbm12, levels=c("w","t","m"))
ypd.dips$nbm45 <- factor(ypd.dips$nbm45, levels=c("w","t","m"))
ypd.dips$nbm58 <- factor(ypd.dips$nbm58, levels=c("w","t","m"))
ypd.dips$Day <- factor(ypd.dips$Day)
ypd.dips$Plate <- factor(ypd.dips$Plate)

#####MODEL - YPD DIPLOIDS, NO HETEROZYGOTES#####
#'write full model
#'plate within day as random effect
dat <- ypd.dips[is.na(ypd.dips$omit)&ypd.dips$type=="m",]
ypd.dips.m.model <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.dips.m.model),residuals(ypd.dips.m.model))
abline(h=0)
hist(residuals(ypd.dips.m.model))
qqnorm(residuals(ypd.dips.m.model))
qqline(residuals(ypd.dips.m.model))
#'plot
boxplot(lgr.ypd ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.dips.m.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'find the least-squares means (and confidence intervals) for each line
ypd.dips.m.lsmeans <- summary(lsmeans(ypd.dips.m.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(ypd.dips.m.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,m,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,m,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
ypd.dips.m.contrasts <- summary(contrast(lsmeans(ypd.dips.m.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(ypd.dips.m.lsmeans, digits=5), "GR.OutliersIncluded/data_output/YPDDipsMMeans.OutIn.csv", row.names=FALSE)
write.csv(format(ypd.dips.m.contrasts, digits=5), "GR.OutliersIncluded/data_output/YPDDipsMContrasts.OutIn.csv", row.names=FALSE)

#####MODEL - YPD DIPLOIDS, INCLUDING HETEROZYGOTES#####
#'write full model
#'plate within day as random effect
dat <- ypd.dips[is.na(ypd.dips$omit),]
ypd.dips.t.model <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.dips.t.model),residuals(ypd.dips.t.model))
abline(h=0)
hist(residuals(ypd.dips.t.model))
qqnorm(residuals(ypd.dips.t.model))
qqline(residuals(ypd.dips.t.model))
#'plot
boxplot(lgr.ypd ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.dips.t.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'find the least-squares means (and confidence intervals) for each line
ypd.dips.t.lsmeans <- summary(lsmeans(ypd.dips.t.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do
con <- summary(contrast(lsmeans(ypd.dips.t.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - t,w,w,w","w,w,w,w - w,t,w,w","w,w,w,w - w,w,t,w","w,w,w,w - w,w,w,t","w,w,w,w - t,t,w,w","w,w,w,w - t,w,t,w","w,w,w,w - t,w,w,t","w,w,w,w - w,t,t,w","w,w,w,w - w,t,w,t","w,w,w,w - w,w,t,t","t,w,w,w - t,t,w,w","t,w,w,w - t,w,t,w","t,w,w,w - t,w,w,t","w,t,w,w - t,t,w,w","w,t,w,w - w,t,t,w",  "w,t,w,w - w,t,w,t","w,w,t,w - t,w,t,w",  "w,w,t,w - w,t,t,w","w,w,t,w - w,w,t,t","w,w,w,t - t,w,w,t","w,w,w,t - w,t,w,t","w,w,w,t - w,w,t,t","t,w,w,w - m,w,w,w","w,t,w,w - w,m,w,w",  "w,w,t,w - w,w,m,w",  "w,w,w,t - w,w,w,m","m,w,w,w - t,t,w,w","m,w,w,w - t,w,t,w","m,w,w,w - t,w,w,t","t,t,w,w - w,m,w,w","w,m,w,w - w,t,t,w",  "w,m,w,w - w,t,w,t","t,w,t,w - w,w,m,w","w,t,t,w - w,w,m,w","w,w,m,w - w,w,t,t","t,w,w,t - w,w,w,m","w,t,w,t - w,w,w,m","w,w,t,t - w,w,w,m","m,w,w,w - m,t,w,w","m,w,w,w - m,w,t,w",  "m,w,w,w - m,w,w,t","w,m,w,w - t,m,w,w",  "w,m,w,w - w,m,t,w","w,m,w,w - w,m,w,t", "w,w,m,w - t,w,m,w",  "w,w,m,w - w,t,m,w","w,w,m,w - w,w,m,t","w,w,w,m - t,w,w,m","w,w,w,m - w,t,w,m","w,w,w,m - w,w,t,m","t,t,w,w - m,t,w,w","t,t,w,w - t,m,w,w","t,w,t,w - m,w,t,w","t,w,t,w - t,w,m,w","t,w,w,t - m,w,w,t","t,w,w,t - t,w,w,m","w,t,t,w - w,m,t,w","w,t,t,w - w,t,m,w","w,t,w,t - w,m,w,t","w,t,w,t - w,t,w,m","w,w,t,t - w,w,m,t","w,w,t,t - w,w,t,m","m,t,w,w - m,m,w,w","t,m,w,w - m,m,w,w","m,w,t,w - m,w,m,w","t,w,m,w - m,w,m,w","m,w,w,t - m,w,w,m","t,w,w,m - m,w,w,m","w,m,t,w - w,m,m,w","w,t,m,w - w,m,m,w","w,m,w,t - w,m,w,m","w,t,w,m - w,m,w,m","w,w,m,t - w,w,m,m","w,w,t,m - w,w,m,m","t,t,w,w - m,m,w,w","t,w,t,w - m,w,m,w","t,w,w,t - m,w,w,m","w,t,t,w - w,m,m,w","w,t,w,t - w,m,w,m","w,w,t,t - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
ypd.dips.t.contrasts <- summary(contrast(lsmeans(ypd.dips.t.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(ypd.dips.t.lsmeans, digits=5), "GR.OutliersIncluded/data_output/YPDDipsTMeans.OutIn.csv", row.names=FALSE)
write.csv(format(ypd.dips.t.contrasts, digits=5), "GR.OutliersIncluded/data_output/YPDDipsTContrasts.OutIn.csv", row.names=FALSE)
